@@ -278,20 +278,18 @@ static void
 select_matching_profile (GstLocationsCombo *combo)
 {
   GstLocationsComboPrivate *priv;
-  GtkTreeModel *model;
   GtkTreeIter iter;
   gchar *current;
   gchar *profile;
   gboolean valid;
 
   priv = combo->_priv;
-  model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->combo));
-  valid = gtk_tree_model_get_iter_first (model, &iter);
+  valid = gtk_tree_model_get_iter_first (priv->model, &iter);
   current = gst_network_locations_get_current (GST_NETWORK_LOCATIONS (combo));
 
   while (valid)
     {
-      gtk_tree_model_get (model, &iter, 0, &profile, -1);
+      gtk_tree_model_get (priv->model, &iter, 0, &profile, -1);
 
       if (profile && current && strcmp (profile, current) == 0)
 	{
@@ -299,7 +297,7 @@ select_matching_profile (GstLocationsCombo *combo)
 	  valid = FALSE;
 	}
       else
-	valid = gtk_tree_model_iter_next (model, &iter);
+	valid = gtk_tree_model_iter_next (priv->model, &iter);
 
       g_free (profile);
     }
